ArenaTypes

Trait ArenaTypes 

pub trait ArenaTypes:
    Clone
    + Debug
    + 'static {
    type Fn: Clone + Debug + FnValueName;
    type Map: Clone + Debug + MapLike;
}
Trait that defines the function and map types used by the arena.

The arena stores function values and persistent maps, but their concrete types depend on the consumer (VM, WASM runtime, codegen, etc.).

Required Associated Types

type Fn: Clone + Debug + FnValueName

The function value type (e.g. FunctionValue in the VM).

type Map: Clone + Debug + MapLike

The persistent map type (e.g. AverMap<u64, (NanValue, NanValue)>).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors